@@ -1,7 +1,7 @@
 from django.contrib import admin
 
 #import local models
-from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, ImportTable
+from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable
 
 #Register models
 admin.site.register(State)
@@ -17,10 +17,7 @@ class QueueInline(admin.StackedInline):
     extra = 3
 
 class BatchAdmin(admin.ModelAdmin):
-    fieldsets = [
-        (None, {'fields': ['destination']}),
-        ]
     inlines = [QueueInline]
 
 admin.site.register(ImportBatch, BatchAdmin)
-admin.site.register(ImportTable)
\ No newline at end of file
+admin.site.register(StagingTable)
\ No newline at end of file
