@@ -157,7 +157,7 @@ class File(models.Model):
 
 
 class ImportBatch(models.Model):
-    destination = models.ForeignKey('ImportTable')
+    #destination = models.ForeignKey('ImportTable')
     name = models.CharField(max_length=200, blank=True, help_text="Optional name for this batch of imports")
     description = models.TextField(blank=True, help_text="Optional description for this batch of imports")
     STATUS_CHOICES = [('NEW', 'Not started'),
@@ -233,7 +233,7 @@ class ImportBatch(models.Model):
     
     def __unicode__(self):
         c_items = ImportQueue.objects.filter(batch=self).count()
-        return "Batch %i [%s]: %d files, destination %s" % (self.pk, self.status, c_items, self.destination)
+        return "Batch %i [%s]: %d files" % (self.pk, self.status, c_items)
 
 
 class ImportQueue(models.Model):
@@ -338,7 +338,7 @@ class ImportQueue(models.Model):
         return True
     
     
-    def fail(self, message=None, logger=None):
+    def fail(self, message=None, logger=None, level='ERROR'):
         self.status = 'FAILED'
         self.complete = datetime.datetime.utcnow().replace(tzinfo=utc)
         self.save()
@@ -349,7 +349,7 @@ class ImportQueue(models.Model):
         return True
     
     
-    def success(self, message=None, logger=None, level='ERROR'):
+    def success(self, message=None, logger=None):
         self.status = 'SUCCESS'
         self.complete = datetime.datetime.utcnow().replace(tzinfo=utc)
         self.save()
@@ -368,7 +368,7 @@ class ImportQueue(models.Model):
     
     
     def record_columns(self):
-        tls = self.batch.destination.source.top_level_source.abbreviation
+        tls = self.file.file_type.source.top_level_source.abbreviation
         cols_saved = 0
         
         if tls == 'HCUP':
@@ -379,7 +379,7 @@ class ImportQueue(models.Model):
             for k, v in augmented.T.to_dict().iteritems():
                 #col_supplemental_meta = pyhcup.db.col_from_invalue(v['informat'])
                 col = Column(
-                    parent_file=self.file,
+                    iq=self,
                     name=v['field'],
                     col_type=v['data_type'].upper(),
                     col_scale=v['scale'],
@@ -397,7 +397,7 @@ class ImportQueue(models.Model):
             for k, v in augmented.T.to_dict().iteritems():
                 # col_supplemental_meta = pyhcup.db.col_from_invalue(v['informat'])
                 col = Column(
-                    parent_file=self.file,
+                    iq=self,
                     name=v['field'],
                     col_type=v['data_type'].upper(),
                     col_scale=v['scale'],
@@ -413,7 +413,7 @@ class ImportQueue(models.Model):
     
     
     def get_meta(self):
-        tls = self.batch.destination.source.top_level_source.abbreviation
+        tls = self.file.file_type.source.top_level_source.abbreviation
         
         if tls == 'HCUP':
             loader = pyhcup.sas.meta_from_sas
@@ -435,14 +435,31 @@ class ImportQueue(models.Model):
     
     
     def __unicode__(self):
-        return "Enqueued item %s [%s]: %s, destination %s" % (self.pk, self.status, self.file.filename, self.batch.destination.name)
+        return "Enqueued item %s [%s]: %s" % (self.pk, self.status, self.file.filename)
 
 
-class ImportTable(models.Model):
-    source = models.ForeignKey('DataSource', help_text="Data source for which this table was created as a 'master' import table")
+class StagingTable(models.Model):
+    """This is a record of staging tables created/populated
+    """
+    #source = models.ForeignKey('DataSource', help_text="Data source for which this table was created as a 'master' import table")
+    imported_via = models.ForeignKey('ImportQueue', blank=True, default=None)
+    #parent = models.ForeignKey
     name = models.CharField(max_length=250, blank=False)
     schema = models.CharField(max_length=250, blank=True)
     database = models.CharField(max_length=250, blank=True, help_text="Leave blank to use default connection specified in Django's setings.py file")
+    
+    CAT_CHOICES = [
+        ('CORE_SOURCE','CORE data in wide format, from source (no derived/updated cols)'),
+        ('CHARGES_SOURCE','Charges data, from source (no wide-to-long conversion)'),
+        ('DAYSTOEVENT_SOURCE','DaysToEvent and VisitLink data, from source (straight csv load)'),
+        ('CHARGES','Charges data in long format (converted from wide source if necessary)'),
+        ('DX','Diagnoses data in long format (extracted from CORE_SOURCE)'),
+        ('PR','Procedures data in long format (extracted from CORE_SOURCE)'),
+        ('UFLAGS','Utilization flag data in long format (generated from CHARGES and PR)'),
+        ('CORE_PROCESSED','CORE data in wide format plus wide data from CHARGES (if not originally present); DaysToEvent and VisitLink fields updated (if not originally present) and wide data from UFlags'),
+    ]
+    category = models.CharField(max_length=100, choices=CAT_CHOICES, blank=False)
+    records = models.IntegerField()
     #TODO: consider adding a col count
     #col_count = models.IntegerField(blank=False)
     
@@ -454,7 +471,7 @@ class ImportTable(models.Model):
     #voided_by = models.ForeignKey(django user object) #unimplemented
     
     def __unicode__(self):
-        return "Master Table %d (%s)" % (self.pk, self.name)
+        return "StagingTable %d (%s, %s)" % (self.pk, self.category, self.name)
 
 
 class Column(models.Model):
@@ -462,16 +479,17 @@ class Column(models.Model):
     #... or if this is to know what columns are available from each imported state (*I think it's this one)
     #... or agnostic of import status, what columns are in a discovered loadfile
     #... or what
-    parent_file = models.ForeignKey('File')
+    iq = models.ForeignKey('ImportQueue')
     name = models.CharField(max_length=200, blank=False,
                             db_index=True)
     
-    TYPE_CHOICES = [('VARCHAR', 'Character (string)'),
-                    ('NUMERIC', 'Numeric (decimal)'),
-                    ('INT', 'Integer (+/- 2.1E8)'),
-                    ('BIGINT', 'Integer (+/- 9.2E18)'),
-                    ('BOOLEAN', 'True/False'),
-                    ]
+    TYPE_CHOICES = [
+        ('VARCHAR', 'Character (string)'),
+        ('NUMERIC', 'Numeric (decimal)'),
+        ('INT', 'Integer (+/- 2.1E8)'),
+        ('BIGINT', 'Integer (+/- 9.2E18)'),
+        ('BOOLEAN', 'True/False'),
+    ]
     col_type = models.CharField(max_length=100, choices=TYPE_CHOICES, blank=False)
     col_scale = models.IntegerField(blank=True, null=True, help_text='Decimal places for numeric fields')
     col_precision = models.IntegerField(blank=True, null=True, help_text='Total sigfigs for numeric fields')
