@@ -25,7 +25,7 @@ from django import db as djangodb
 
 
 # local project and app packages
-from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, ImportTable
+from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable
 from djhcup_staging.utils.misc import dead_batches
 
 
@@ -53,7 +53,7 @@ def reset_dead():
     
     1. batch is started but not complete and celery task is no longer held in queue or being processed
         --> ignore any related ImportQueue objects where completed is not null and status is SUCCESS
-        --> delete db records in related ImportTable for state-year combinations on incomplete ImportQueue objects
+        --> delete db records in related StagingTable for state-year combinations on incomplete ImportQueue objects
         Code is written in for this below
     """
     
@@ -129,7 +129,7 @@ def batch_import(self, batch_id):
     batch.save()
     
     enqueued = ImportQueue.objects.filter(batch=batch)
-    destination = batch.destination
+    #destination = batch.destination
     logger.info('Found %s' % (batch))
     
     if batch.complete:
@@ -143,19 +143,8 @@ def batch_import(self, batch_id):
         logger.warning(response)
         batch.fail()
         return True
-    
-    #make sure the items in the batch have the same data source as the destination table
-    elif not all(x.file.file_type.source == destination.source for x in enqueued):
-        response = 'One or more items enqueued in batch %i has a different data source than was used to generate the master table intended to receive data (destination master table data source is %s), and therefore the batch will not be run' % (batch.pk, batch.destination.source)
-        logger.error(response)
-        [logger.error('%s has data source %s' % (x, x.file.file_type.source)) for x in enqueued if x.file.file_type.source != destination.source]
-        batch.fail()
-        return False
-        
+
     else:
-        #proceed with batch import
-        logger.info('All enqueued files appear to have same data source as destination (%s)' % destination.source)
-        
         batch_begin = datetime.datetime.utcnow().replace(tzinfo=utc)
         batch.start = batch_begin
         batch.status = 'IN PROCESS'
@@ -177,12 +166,16 @@ def batch_import(self, batch_id):
 def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
     load = ImportQueue.objects.get(pk=importqueue_pk)
     
+    """
+    # TODO: Sim. to the batch_import blocks that are commented out above, these bits are more important for an integration step. They exist to prevent double-loading into a common table, but I don't necessarily want to prevent making duplicate staging tables for a given File object.
+    
     destination = load.batch.destination
-    similar_load_qs = ImportQueue.objects.filter(batch__destination=destination,
-                                                 file__state=load.file.state,
-                                                 file__year=load.file.year,
-                                                 file__file_type__source=load.file.file_type.source
-                                                 )
+    similar_load_qs = ImportQueue.objects.filter(
+        batch__destination=destination,
+        file__state=load.file.state,
+        file__year=load.file.year,
+        file__file_type__source=load.file.file_type.source
+        )
     similar_completed = similar_load_qs.filter(complete__isnull=False, status='SUCCESS')
     similar_started = similar_load_qs.filter(start__isnull=False)
     
@@ -200,34 +193,35 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
         return False
 
     else:
-        # proceed with making the file happen
-        load.status = 'QUEUED'
-        load.save()
-        
-        logger.info('Queued for dispatch: %s' % (load))
-        
-        dsabbr = destination.source.abbreviation
-        
-        # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
-        if ('psycopg2' in DB_BACKEND and (
-                ((dsabbr.upper() in ['CORE', 'BASE', 'CHGS']) or
-                 (dsabbr.upper() in ['CHGS'] and meta_is_long(load.get_meta()))
-                    )
+    """
+    # proceed with making the file happen
+    load.status = 'QUEUED'
+    load.save()
+    
+    logger.info('Queued for dispatch: %s' % (load))
+    
+    dsabbr = load.file.file_type.source.abbreviation
+    
+    # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
+    if ('psycopg2' in DB_BACKEND and (
+            ((dsabbr.upper() in ['CORE', 'BASE', 'CHGS']) or
+                (dsabbr.upper() in ['CHGS'] and meta_is_long(load.get_meta()))
                 )
-            ):
-            # do it Rockapella
-            logger.info('Sending to pg_import_file: %s' % (load))
-            pg_import_file.delay(load.pk)
-            return True
-        
-        else:
-            logger.info('Sending to chunk_import_file: %s' % (load))
-            chunk_import_file.delay(load.pk)
-            return True
+            )
+        ):
+        # do it Rockapella
+        logger.info('Sending to pg_import_file: %s' % (load))
+        pg_import_file.delay(load.pk)
+        return True
+    
+    else:
+        logger.info('Sending to chunk_import_file: %s' % (load))
+        chunk_import_file.delay(load.pk)
+        return True
 
 
 @celery.shared_task(bind=True, ignore_result=True)
-def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
+def pg_import_file(self, importqueue_pk, drop_rawload=True):
     """Assumes psycopg2 availability.
     """
     
@@ -239,11 +233,14 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     load.log('Beginning import with psycopg2',
              level='INFO', logger=logger, status='IN PROCESS')
     
-    destination = load.batch.destination
+    # TODO: move to integration
+    #destination = load.batch.destination
     
     load.log('Begin import',
              level='INFO', logger=logger)
     
+    """
+    TODO: Re-enable if appropriate; omitted for convenience atm
     cols_saved = load.record_columns()
     if cols_saved > 0:
         load.log('Columns saved: %s' % (load),
@@ -251,15 +248,25 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     else:
         load.log('No columns saved',
                 level='WARNING', logger=logger)
+    """
     
-    table = destination.name
-    schema = destination.schema
+    #schema = destination.schema
     state = load.file.state.abbreviation
     year = load.file.year
-    dsabbr = destination.source.abbreviation
+    dsabbr = load.file.file_type.source.abbreviation
     
+    if dsabbr == 'CORE':
+        # this is a first-pass CORE import
+        stcat = 'SID_CORE_SOURCE'
+        # TODO: Expand for non-SID nomenclature
+    elif dsabbr == 'CHGS':
+        stcat = 'SID_CHARGES_SOURCE'
+    else:
+        raise Exception("wtf are you doing? you know this code is all borked right now.")
+    
+    stg_table_name = '_'.join(str(x) for x in [state, year, 'stg', stcat])
     handle = load.file.open()
-    
+
     # establish connection directly with psycopg2
     import psycopg2
     cnxn = psycopg2.connect(
@@ -273,74 +280,101 @@ def pg_import_file(self, importqueue_pk, drop_intermediate_tables=True):
     # get helper functions
     from pyhcup.db import pg_rawload, pg_staging, pg_shovel, pg_wtl_shovel, pg_drop
     
-    # let 'er rip
-    meta = load.get_meta()
     
-    load.log('Creating raw import table via pg_rawload()',
-            level='INFO', logger=logger)
-    rawload = pg_rawload(cnxn, handle, meta)
-    load.log('Raw import table %s populated' % (rawload),
-            level='INFO', logger=logger)
-    
-    if load.file.file_type.source.abbreviation in pyhcup.parser.LONG_MAPS.keys():
-        pk_fields = None
-        load.log('Staging will be done with no primary key',
-                level='INFO', logger=logger)
-    else:
-        pk_fields = ['key', 'state', 'year']
-        load.log('Staging will be done with primary key %s' % (pk_fields),
-                level='INFO', logger=logger)
-    
-    load.log('Creating staging table via pg_staging()',
-            level='INFO', logger=logger)
-    staging = pg_staging(cnxn, rawload, meta, state, year, pk_fields=pk_fields)
-    load.log('Staging table populated: %s' % (staging[0]),
-            level='INFO', logger=logger)
-    
-    
-    if dsabbr in ['CHGS'] and not meta_is_long(meta):
-        # wide charges should get wide-to-long shoveled
-        category = dsabbr
-        load.log('This is a wide-to-long pg load',
-                level='INFO', logger=logger)
-        #logger.info()
-        load.log('Inserting contents of staging table %s to master table %s' % (staging[0], table),
-                level='INFO', logger=logger)
-        affected_rows = pg_wtl_shovel(cnxn, meta, category, staging[0], table)
-        #logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
-        load.log('Inserted contents of staging table %s to master table %s (%s rows)' % (staging[0], table, affected_rows),
-                level='INFO', logger=logger)
-    
-    else:
-        fields = [x for x in meta.field if x.lower() not in ['state', 'year']]
-        fields += ['state', 'year']
+    # segregate the csv loads from the non-csv loads
+    if str(load.file.filename).split('.')[-1] == 'csv':
+        # just do a csv load, and assume a header is present
         
-        #logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
-        load.log('Inserting contents of staging table %s to master table %s' % (staging[0], table),
+        affected_rows = 0
+        
+    else:
+        # use the old style code
+        # let 'er rip
+        meta = load.get_meta()
+        
+        load.log('Creating raw import table via pg_rawload()',
                 level='INFO', logger=logger)
-        affected_rows = pg_shovel(cnxn, staging[0], table, fields)
-        logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
-        load.log('Inserted contents of staging table %s to master table %s (%s rows)' % (staging[0], table, affected_rows),
+        rawload = pg_rawload(cnxn, handle, meta)
+        load.log('Raw import table %s populated' % (rawload),
                 level='INFO', logger=logger)
         
-    if drop_intermediate_tables:
-        drop_targets = [rawload, staging[0]]
-        #logger.info('Dropping intermediate tables %s: %s' % (drop_targets, load))
-        load.log('Dropping intermediate tables: %s' % (drop_targets),
-                level='INFO', logger=logger)
-        for dtbl in drop_targets:
-            #logger.info('Dropping intermediate table %s: %s' % (dtbl, load))
-            load.log('Dropping intermediate table: %s' % (dtbl),
+        if load.file.file_type.source.abbreviation in pyhcup.parser.LONG_MAPS.keys():
+            pk_fields = None
+            load.log('Staging will be done with no primary key',
                     level='INFO', logger=logger)
-            drop_result = pg_drop(cnxn, dtbl)
-            if drop_result == True:
-                logger.info('Successfully dropped intermediate table %s: %s' % (dtbl, load))
-                load.log('Successfully dropped intermediate table: %s' % (dtbl),
+        else:
+            pk_fields = ['key', 'state', 'year']
+            load.log('Staging will be done with primary key %s' % (pk_fields),
+                    level='INFO', logger=logger)
+        
+        load.log('Creating staging table via pg_staging()',
+                level='INFO', logger=logger)
+        staging = pg_staging(cnxn, rawload, meta, state, year, pk_fields=pk_fields,
+                             table_name=stg_table_name)
+        load.log('Staging table populated: %s' % (stg_table_name),
+                level='INFO', logger=logger)
+        
+        affected_rows = staging[1]
+        
+        # save info about this import in a StagingTable object
+        imported = StagingTable(
+            imported_via = load,
+            name = stg_table_name,
+            category = stcat,
+            records = affected_rows
+        )
+        
+        imported.save()
+        
+        load.log('StagingTable %s recorded for %s' % (stg_table_name, imported.pk))
+        
+        
+        if dsabbr in ['CHGS'] and not meta_is_long(meta):
+            # wide charges should get wide-to-long shoveled
+            # TODO: adjust this using StagingTable records
+            category = dsabbr
+            load.log('This is a wide-to-long pg load',
+                    level='INFO', logger=logger)
+            #logger.info()
+            load.log('Inserting contents of staging table %s to master table %s' % (staging[0], table),
+                    level='INFO', logger=logger)
+            affected_rows = pg_wtl_shovel(cnxn, meta, category, staging[0], stg_table_name)
+            #logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], table, affected_rows, load))
+            load.log('Inserted contents of staging table %s to master table %s (%s rows)' % (staging[0], raw_table_name, affected_rows),
+                    level='INFO', logger=logger)
+        """
+        else:
+            fields = [x for x in meta.field if x.lower() not in ['state', 'year']]
+            fields += ['state', 'year']
+            
+            #logger.info('Inserting contents of staging table %s to master table %s: %s' % (staging[0], table, load))
+            load.log('Inserting contents of staging table %s to master table %s' % (staging[0], table),
+                    level='INFO', logger=logger)
+            affected_rows = pg_shovel(cnxn, staging[0], table, fields)
+            logger.info('Inserted contents of staging table %s to master table %s (%s rows): %s' % (staging[0], raw_table_name, affected_rows, load))
+            load.log('Inserted contents of staging table %s to master table %s (%s rows)' % (staging[0], raw_table_name, affected_rows),
+                    level='INFO', logger=logger)
+        """
+        
+        if drop_rawload:
+            # TODO: Rework this section a little more elegantly
+            drop_targets = [rawload]#, staging[0]]
+            #logger.info('Dropping intermediate tables %s: %s' % (drop_targets, load))
+            load.log('Dropping intermediate tables: %s' % (drop_targets),
+                    level='INFO', logger=logger)
+            for dtbl in drop_targets:
+                #logger.info('Dropping intermediate table %s: %s' % (dtbl, load))
+                load.log('Dropping intermediate table: %s' % (dtbl),
                         level='INFO', logger=logger)
-            else:
-                logger.error('Failed to drop %s: %s' % (dtbl, load))
-                load.log('Failed to drop: %s' % (dtbl),
-                        level='ERROR', logger=logger)
+                drop_result = pg_drop(cnxn, dtbl)
+                if drop_result == True:
+                    logger.info('Successfully dropped intermediate table %s: %s' % (dtbl, load))
+                    load.log('Successfully dropped intermediate table: %s' % (dtbl),
+                            level='INFO', logger=logger)
+                else:
+                    logger.error('Failed to drop %s: %s' % (dtbl, load))
+                    load.log('Failed to drop: %s' % (dtbl),
+                            level='ERROR', logger=logger)
     
     # affected_rows will evaluate un-True in the case of any troubles
     if affected_rows:
