@@ -22,7 +22,7 @@ from django.db import transaction as tx
 
 # local project and app packages
 import djhcup_staging
-from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, ImportTable
+from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable
 from djhcup_staging.utils.misc import dead_batches
 
 
